@@ -1,4 +1,5 @@
 import os
+from dataclasses import dataclass
 from enum import Enum
 from typing import Any, List, Optional, Tuple
 import PyInquirer
@@ -8,6 +9,7 @@ from fds.domain.commands import AddCommands
 from fds.domain.constants import MAX_THRESHOLD_SIZE
 from fds.logger import Logger
 from fds.services.pretty_print import PrettyPrint
+from fds.services.types import DvcAdd
 from fds.utils import get_size_of_path, convert_bytes_to_readable, convert_bytes_to_string, execute_command, \
     append_line_to_file, check_git_ignore, check_dvc_ignore, does_file_exist, \
     construct_dvc_url_from_git_url_dagshub
@@ -18,8 +20,15 @@ class DvcChoices(Enum):
     ADD_TO_DVC = "Add to DVC"
     ADD_TO_GIT = "Add to Git"
     IGNORE = "Ignore"
+    SKIP = "Skip"
     STEP_INTO = "Step Into"
 
+@dataclass
+class AddToDvc:
+    file_to_add: Optional[str]
+    file_to_ignore: Optional[str]
+    file_to_skip: Optional[str]
+
 
 class DVCService(object):
     """
@@ -84,8 +93,12 @@ class DVCService(object):
             "value": DvcChoices.ADD_TO_GIT.value
         }, {
             "key": "i",
-            "name": "Ignore - Add to .gitignore",
+            "name": "Ignore - Add to .gitignore and .dvcignore",
             "value": DvcChoices.IGNORE.value
+        }, {
+            "key": "s",
+            "name": "Skip - Don't add the file/folder to DVC or Git",
+            "value": DvcChoices.SKIP.value
         }]
         if os.path.isdir(file_or_dir_to_check):
             choices.append({
@@ -110,25 +123,25 @@ class DVCService(object):
     def __get_to_add_to_dvc(self,
                             file_or_dir_to_check: str,
                             dirs: List[str],
-                            file_dir_type: str) -> Tuple[Optional[str], Optional[str]]:
+                            file_dir_type: str) -> AddToDvc:
         """
         Returns the tuple (file/folder to be added to dvc, folder to be ignored)
         :param file_or_dir_to_check: File or folder to check if its to be added or ignored
         :param dirs: folders in the current walk
         :param file_dir_type: Type indicating whether its file or Dir
-        :return: (file/folder to be added to dvc, folder to be ignored)
+        :return: AddToDvc dataclass
         """
         if not self.__should_skip_list_add(file_or_dir_to_check):
             path_size = get_size_of_path(file_or_dir_to_check)
             # Dont need to traverse deep in case of dir, if the dir is below the threshold size
             if path_size < MAX_THRESHOLD_SIZE:
                 if os.path.isdir(file_or_dir_to_check):
-                    return None, file_or_dir_to_check
-                return None, None
+                    return AddToDvc(None, file_or_dir_to_check, None)
+                return AddToDvc(None, None, None)
             # If the file or dir is greater than threshold and is dvc ignored
             dvc_output = check_dvc_ignore(file_or_dir_to_check)
             if convert_bytes_to_string(dvc_output.stdout) != '':
-                return None, file_or_dir_to_check
+                return AddToDvc(None, file_or_dir_to_check, None)
             # Show the message only when files are shown and only once per add
             if self.selection_message_count == 0:
                 self.selection_message_count = 1
@@ -139,24 +152,33 @@ class DVCService(object):
             if answers["selection_choice"] == DvcChoices.ADD_TO_DVC.value:
                 # Dont need to traverse deep
                 [dirs.remove(d) for d in list(dirs)]
-                return file_or_dir_to_check, None
+                return AddToDvc(file_or_dir_to_check, None, None)
             elif answers["selection_choice"] == DvcChoices.ADD_TO_GIT.value:
                 # Dont need to traverse deep
                 [dirs.remove(d) for d in list(dirs)]
-                return None, None
+                return AddToDvc(None, None, None)
+            elif answers["selection_choice"] == DvcChoices.SKIP.value:
+                # Dont need to traverse deep as we are skipping the folder/file
+                [dirs.remove(d) for d in list(dirs)]
+                return AddToDvc(None, None, file_or_dir_to_check)
             elif answers["selection_choice"] == DvcChoices.IGNORE.value:
                 # We should ignore the ./ in beginning when adding to gitignore
                 # Add files to gitignore
                 append_line_to_file(".gitignore",
                                     file_or_dir_to_check[file_or_dir_to_check.startswith('./') and 2:])
+                # Also add to dvcignore
+                append_line_to_file(".dvcignore",
+                                    file_or_dir_to_check[file_or_dir_to_check.startswith('./') and 2:])
                 # Dont need to traverse deep
                 [dirs.remove(d) for d in list(dirs)]
-                return None, None
-        return None, None
+                return AddToDvc(None, None, None)
+        return AddToDvc(None, None, None)
 
-    def __add(self, add_argument: str):
+    def __add(self, add_argument: str) -> DvcAdd:
         chosen_files_or_folders = []
         # Keep track of dirs which are below threshold size, so we dont iterate the files inside these dirs
+        ignored_dirs = []
+        # Skipped files/folders are those that are not to be tracked by git or dvc and just skipped by the users
         skipped_dirs = []
         # May be add all the folders given in the .gitignore
         folders_to_exclude = ['.git', '.dvc']
@@ -174,11 +196,13 @@ class DVCService(object):
             # Skip the already added files/folders
             self.__skip_already_added(root, dirs)
             # First check root
-            (folder_to_add, skipped_dir) = self.__get_to_add_to_dvc(root, dirs, "Dir")
-            if skipped_dir is not None:
-                skipped_dirs.append(skipped_dir)
-            if folder_to_add is not None:
-                chosen_files_or_folders.append(folder_to_add)
+            add_to_dvc = self.__get_to_add_to_dvc(root, dirs, "Dir")
+            if add_to_dvc.file_to_ignore is not None:
+                ignored_dirs.append(add_to_dvc.file_to_ignore)
+            if add_to_dvc.file_to_add is not None:
+                chosen_files_or_folders.append(add_to_dvc.file_to_add)
+            if add_to_dvc.file_to_skip is not None:
+                skipped_dirs.append(add_to_dvc.file_to_skip)
             else:
                 # Only if they dont select the directory then ask for files,
                 # otherwise ignore asking about files of the directory
@@ -187,28 +211,30 @@ class DVCService(object):
                 # because he doesn't want the entire directory to be added.
 
                 # If the root is skipped because it is below threshold size then we don't need to check files
-                if root in skipped_dirs:
+                if root in ignored_dirs:
                     continue
                 # Then check files
                 for file in files:
-                    (file_to_add, skipped_dir) = self.__get_to_add_to_dvc(f"{root}/{file}", [], "File")
-                    if skipped_dir is not None:
-                        skipped_dirs.append(skipped_dir)
-                    if file_to_add is not None:
-                        chosen_files_or_folders.append(file_to_add)
+                    add_to_dvc = self.__get_to_add_to_dvc(f"{root}/{file}", [], "File")
+                    if add_to_dvc.file_to_ignore is not None:
+                        ignored_dirs.append(add_to_dvc.file_to_ignore)
+                    if add_to_dvc.file_to_add is not None:
+                        chosen_files_or_folders.append(add_to_dvc.file_to_add)
+                    if add_to_dvc.file_to_skip is not None:
+                        skipped_dirs.append(add_to_dvc.file_to_skip)
         self.logger.debug(f"Chosen folders to be added to dvc are {chosen_files_or_folders}")
-        if len(chosen_files_or_folders) == 0:
-            return "Nothing to add in DVC"
+        if len(chosen_files_or_folders) > 0:
+            self.printer.warn("Adding to dvc...")
+            # executing a oneliner for performance
+            execute_command(['dvc', 'add'] + chosen_files_or_folders, capture_output=False)
+        return DvcAdd(chosen_files_or_folders, skipped_dirs)
 
-        self.printer.warn("Adding to dvc...")
-        progress_tracker = Bar('Processing', max=len(chosen_files_or_folders))
-        for add_to_dvc in chosen_files_or_folders:
-            execute_command(["dvc", "add", add_to_dvc])
-            progress_tracker.next()
-        progress_tracker.finish()
-        return "DVC add successfully executed"
-
-    def add(self, add_argument: str) -> Any:
+    def add(self, add_argument: str) -> DvcAdd:
+        """
+        Add files into dvc
+        :param add_argument: add_argument which is one of the AddCommands Enum
+        :return: DvcAdd dataclass
+        """
         return self.__add(add_argument)
 
     def commit(self, auto_confirm: bool) -> Any:
