@@ -42,3 +42,6 @@ class IntegrationTestCase(unittest.TestCase):
             self.create_dummy_file(f"{dvc_path}/file-{i}", 10)
         # creating one large file
         self.create_dummy_file("large_file", 11 * 1024)
+
+    def get_remote_url_for_test(self):
+        return "https://dagshub.com/Dean/hello-world.git"
